================================
:code:`Trakt['users/*/ratings']`
================================

.. automodule:: trakt.interfaces.users.ratings

  .. autoclass:: UsersRatingsInterface
    :members: get
    :undoc-members:
